

# This script provides the evolution of water scarcity condition during different drought condition

library(readxl)
library(sf)
library(ggplot2)
library(ggspatial)
library(dplyr)
library(colorspace)
library(RColorBrewer)
library(tidyverse)

path.intermediate_data <- 'folder/'

# SPEI values
for (i in 12) {
  
  print(i)
  
  spei_index <- i
  
  # Extract only the relevant region
  target_months <- c(3,6,9,12)
  target_months_names <- c('March','June','September','December')
  
  seas_wei_names <- c('Q1','Q2','Q3','Q4')
  
  # SPEI: period 1990-2019
  mask_europe <- readRDS(file=paste(path.intermediate_data, 'rdata/EEA_subbasin_mask_europe_era5land_COMBINED_REGIONS_1990-2019.Rds', sep=""))
  Entity_spei <- sort(mask_europe$region_code)
  rm(mask_europe)
  
  regions <- 'EEA_subbasin'
  data_spei_obs <- readRDS(file=paste(path.intermediate_data, 'rdata/spei/data_pet_fao_spei_',i,'_',regions,'_COMBINED_REGIONS_1950-2019.Rds', sep=""))
  names(dim(data_spei_obs)) <- c('Month','Year','Entity')
  
  data_spei_obs <- data_spei_obs[target_months,40:69,]
  
  # SPEI: period 1950-2019
  
  # mask_europe <- readRDS(file=paste(path.intermediate_data, 'rdata/EEA_subbasin_mask_europe_era5land_COMBINED_REGIONS_1950-2019.Rds', sep=""))
  # Entity_spei <- sort(mask_europe$region_code)
  # rm(mask_europe)
  
  # regions <- 'EEA_subbasin'
  # data_spei_obs <- readRDS(file=paste(path.intermediate_data, 'rdata/spei/data_pet_fao_spei_',i,'_',regions,'.Rds', sep=""))
  # data_spei_obs <- data_spei_obs
  # names(dim(data_spei_obs)) <- c('Month','Year','Entity')
  
  # WEI array
  regions <-  'EEA_riverbasin'
  data_array <- readRDS(file=paste(path.intermediate_data, 'rdata/exposure_data/data_wei_',regions,'.Rds', sep=""))
  
  array_wei <- data_array$array
  wei_index_seasonal <- s2dv::Reorder(array_wei, order = c('Season','Year','Entity'))
  
  Entity_wei <- sort(data_array$Entity) 
  Year <- data_array$Year
  Season <- data_array$Season
  
  # European region classification
  regions <-  'EEA_riverbasin'
  regions_europe_sb_unique <- readRDS(file=paste(path.intermediate_data, 'rdata/exposure_data/data_europe_regions_',regions,'.Rds', sep=""))
  Entity_european_regions <- regions_europe_sb_unique$SB_REF_V16
  
  # Finding common codes
  
  # common_codes <- intersect(Entity_wei,Entity_spei)
  
  common_codes <- readRDS(file=paste(path.intermediate_data, 'LANCET_2023_final/rdata/exposure_data/common_codes_all_data_available_1990_2019_EEA_riverbasin.Rds', sep=""))
  # add_codes <- c("WSB0000103","WSB0000162","WSB0000274","WSB0000276","WSB0000277","WSB0000278","WSB0000322","WSB0000069","WSB0000070","WSB0000418",
  #                "WSB0000321","WSB0000411","WSB0000301","WSB0000315","WSB0000540")
  # common_codes_x <- c(common_codes,add_codes)
  # common_codes <- sort(common_codes_x)
  common_codes <- setdiff(common_codes, "WSB0000508") # I remove "WSB0000508" since it is creating problems. The shape file has four different polygons for the same code. See 315-320th position of Entity_spei
  
  locations_spei <- which(Entity_spei %in% common_codes)
  locations_wei <- which(Entity_wei %in% common_codes)
  locations_european_region <- which(Entity_european_regions %in% common_codes)
  
  # Subselect only those regions where we have common data
  
  data_spei_obs <- data_spei_obs[,,locations_spei]
  wei_index_seasonal <- wei_index_seasonal[,,locations_wei]
  
  regions_europe_unique <- regions_europe_sb_unique %>%
    filter(SB_REF_V16 %in% common_codes)
  
  # For extrme severe
  ranges_spei_all <- c(-Inf, -1.6, -1.3, -0.8, 0, 0.8, 1.3, 1.6, Inf) # 'exceptional' 'extreme' 'severe' 'moderate'  'normal'
  ranges_wei_all <- c(-Inf, 10, 20, 40, Inf)
  
  # For severe
  # ranges_spei_all <- c(-Inf, -1.3, -0.8, 0, 0.8, 1.3, Inf) # 'exceptional' 'extreme' 'severe' 'moderate'  'normal'
  # ranges_wei_all <- c(-Inf, 10, 20, Inf)
  
  data_count_table_perc <- array(NA, c(length(target_months),length(seas_wei_names),4,(length(ranges_spei_all) - 1),(length(ranges_wei_all) - 1)))
  names(dim(data_count_table_perc)) <- c('Month','WEI_quaterly','Europe_region','Drought_cat','WEI_cat')
  
  data_count_total_events <- array(NA, c(length(target_months),length(seas_wei_names),4,(length(ranges_spei_all) - 1)))
  names(dim(data_count_total_events)) <- c('Month','WEI_quaterly','Europe_region','Number_Drought_cat')
  
    for (seas in 1:4) {
      
      tar_mon <- target_months[seas]
      target_months_name <- target_months_names[seas]
      
      seas_wei_name <- seas_wei_names[seas]
      
      data_spei_obs_mon <- data_spei_obs[seas,11:20,]  # 11:20 for 2000-2009 / 21:30 for 2010-2019
      wei_index_seasonal_seas <- wei_index_seasonal[seas,11:20,]  # 11:20 for 2000-2009 / 21:30 for 2010-2019
      
      data_spei_obs_mon_eu <- data_spei_obs_mon
      wei_index_seasonal_seas_eu <- wei_index_seasonal_seas
      
      part_of_europes <- unique(regions_europe_unique$europe_part)
      
      
      for (eur_reg in 1:length(part_of_europes)) {
        
        part_of_europe <- part_of_europes[eur_reg]
        
        data_spei_obs_mon_test <- data_spei_obs_mon_eu[,which(regions_europe_unique$europe_part == part_of_europe)]
        wei_index_seasonal_seas_test <- wei_index_seasonal_seas_eu[,which(regions_europe_unique$europe_part == part_of_europe)]
        
        range_category_spei <- cut(data_spei_obs_mon_test, breaks = ranges_spei_all, labels = FALSE, include.lowest = TRUE, na.pass = TRUE)
        range_category_wei <- cut(wei_index_seasonal_seas_test, breaks = ranges_wei_all, labels = FALSE, include.lowest = TRUE, na.pass = TRUE)
        
        # Locate NA values in range_category_spei and range_category_wei
        na_indices_spei <- is.na(range_category_spei)
        na_indices_wei <- is.na(range_category_wei)
        
        na_indices_combined <- na_indices_spei | na_indices_wei
        na_indices_ind <- which(na_indices_combined == TRUE)
        
        # Remove values at NA locations in both columns
        if (length(na_indices_ind) > 0) {
          range_category_spei <- range_category_spei[-na_indices_ind]
          range_category_wei <- range_category_wei[-na_indices_ind]
        }
        
        df_range <- data.frame(range_category_spei=range_category_spei, range_category_wei= range_category_wei)
        
        count_table <- table(df_range$range_category_spei, df_range$range_category_wei)
        count_table_rowsum <- rowSums(count_table)
        count_table_perc <- (count_table/count_table_rowsum)*100
        
        ################################################################################################################
        ############## The following operation is done to make sure we always have the same rows and column ############
        
        # Define the desired number of rows and columns
        desired_rows <- length(ranges_spei_all) - 1
        desired_cols <- length(ranges_wei_all) - 1
        
        # Check the current dimensions of count_table_perc
        current_rows <- nrow(count_table_perc)
        current_cols <- ncol(count_table_perc)
        
        # Define the desired row names
        desired_row_names <- as.character(1:desired_rows)
        desired_col_names <- as.character(1:desired_cols)
        
        # Get the current row names
        current_row_names <- row.names(count_table_perc)
        current_col_names <- colnames(count_table_perc)
        
        # Check and add missing rows
        missing_rows <- setdiff(desired_row_names, current_row_names)
        if (length(missing_rows) > 0) {
          new_rows <- matrix(0, nrow = length(missing_rows), ncol = current_cols)
          rownames(new_rows) <- as.character(missing_rows)
          count_table_perc <- rbind(count_table_perc, new_rows)
        }
        
        # Check and add missing columns
        missing_cols <- setdiff(desired_col_names, current_col_names)
        if (length(missing_cols) > 0) {
          new_cols <- matrix(0, nrow = desired_rows, ncol = length(missing_cols))
          colnames(new_cols) <- as.character(missing_cols)
          count_table_perc <- cbind(count_table_perc, new_cols)
        }
        
        # Sort rows and columns
        count_table_perc <- count_table_perc[order(row.names(count_table_perc)), order(colnames(count_table_perc))]
        
        ###########################################################################################################
        
        
        data_count_table_perc[seas,seas,eur_reg,,] <- count_table_perc
        data_count_total_events[seas,seas,eur_reg,] <- count_table_rowsum
        
        
      }
    }
  
  data_count_table <- list()
  data_count_table$array <- data_count_table_perc
  data_count_table$data_count_total_events <- data_count_total_events
  data_count_table$target_months <- target_months
  data_count_table$seas_wei_names <- seas_wei_names
  data_count_table$part_of_europes <- part_of_europes
  data_count_table$ranges_spei_all <- ranges_spei_all
  data_count_table$ranges_wei_all <- ranges_wei_all
  
  # For extreme severe
  saveRDS(data_count_table, file=paste(path.intermediate_data, 'rdata/exposure_data/4_percentage_events_fin/data_count_percentage_DROUGHT_severe_extreme_WEI_severe_extreme_YEAR_2000_2009_regions_with_all_values.Rds', sep=""))
  
  # For severe
  # saveRDS(data_count_table, file=paste(path.intermediate_data, 'rdata/exposure_data/4_percentage_events_fin/data_count_percentage_DROUGHT_severe_WEI_severe_YEAR_2000_2009_regions_with_all_values.Rds', sep=""))
  
}