
##################################################################################
## Plot: What was the water stress condition during different drought condition ##
##################################################################################

library(ggplot2, lib.loc = "/home/Earth/bsolaraj/R/x86_64-pc-linux-gnu-library/4.1" )
library(dplyr, lib.loc = "/home/Earth/bsolaraj/R/x86_64-pc-linux-gnu-library/4.1")
library(tidyverse)

path.intermediate_data <- 'folder/'
path.final_data <- 'data_out/'

# Load data

data_count_2000 <- readRDS(file=paste(path.intermediate_data, 'rdata/exposure_data/4_percentage_events_fin/data_count_percentage_DROUGHT_severe_extreme_WEI_severe_extreme_YEAR_2000_2009_regions_with_all_values.Rds', sep=""))
part_of_europes <- data_count_2000$part_of_europes
seas_wei_names <- data_count_2000$seas_wei_names
drought_count_2000 <- data_count_2000$data_count_total_events
data_count_2000 <- data_count_2000$array       

data_count_2010 <- readRDS(file=paste(path.intermediate_data, 'rdata/exposure_data/4_percentage_events_fin/data_count_percentage_DROUGHT_severe_extreme_WEI_severe_extreme_YEAR_2010_2019_regions_with_all_values.Rds', sep=""))
drought_count_2010 <- data_count_2010$data_count_total_events
data_count_2010 <- data_count_2010$array  

spei_index <- 12
target_months <- c(3,6,9,12)
target_months_names <- c('March','June','September','December')

for (seas in 1:4) {
  
  tar_mon <- target_months[seas]
  target_months_name <- target_months_names[seas]
  
  seas_wei_name <- seas_wei_names[seas]
  
  for (eur_reg in 1:length(part_of_europes)) {
    
    part_of_europe <- part_of_europes[eur_reg]
    
data_past_10 <- data_count_2000[seas,seas,eur_reg,1:3,]   
data_past_10_drought_count <- drought_count_2000[seas,seas,eur_reg,1:3] 

data_recent_10 <- data_count_2010[seas,seas,eur_reg,1:3,] 
data_recent_10_drought_count <- drought_count_2010[seas,seas,eur_reg,1:3] 

data_past_10 <- data_past_10[3:1,]
data_past_10_drought_count <- data_past_10_drought_count[3:1]

data_recent_10 <- data_recent_10[3:1,]
data_recent_10_drought_count <- data_recent_10_drought_count[3:1]

# Drough change percentage:

drought_perc_change <- ((data_recent_10_drought_count - data_past_10_drought_count) / data_past_10_drought_count)*100
drought_perc_change <- round(drought_perc_change)

df_data_past_10 <- data.frame(
  Row = factor(c('Moderate', 'Severe', 'Extreme'), levels = c('Moderate', 'Severe', 'Extreme')),
  `No_stress` = data_past_10[, 1],
  `moderate_stress` = data_past_10[, 2],
  `stress` = data_past_10[, 3],
  `severe_stress` = data_past_10[, 4]
)

df_data_recent_10 <- data.frame(
  Row = factor(c('Moderate', 'Severe', 'Extreme'), levels = c('Moderate', 'Severe', 'Extreme')),
  `No_stress` = data_recent_10[, 1],
  `moderate_stress` = data_recent_10[, 2],
  `stress` = data_recent_10[, 3],
  `severe_stress` = data_recent_10[, 4]
)

# Combine the data frames
combined_df <- rbind(cbind(df_data_past_10, Year = "Past 10"), cbind(df_data_recent_10, Year = "Recent 10"))

# Convert the data from wide to long format
combined_df_long <- tidyr::pivot_longer(combined_df, cols = -c(Row, Year), names_to = "Stress_Level", values_to = "Value")

# Define the order of the Stress_Level factor
stress_levels <- c("No_stress", "moderate_stress", "stress", "severe_stress")

# Convert the Stress_Level column to a factor with the desired order
combined_df_long$Stress_Level <- factor(combined_df_long$Stress_Level, levels = stress_levels)

# Plotting

plot <- ggplot(combined_df_long,                         # Draw barplot with grouping & stacking
       aes(x = Year,
           y = Value,
           fill = Stress_Level)) +
  geom_bar(stat = "identity",
           position = "stack") +
  # facet_grid(~ Row,  labeller = labeller(Row = c("Moderate" = paste0('Moderate drought \n(',drought_perc_change[1],'%)'),
  #                                                "Severe" = paste0('Severe drought \n (',drought_perc_change[2],'%)'),
  #                                                "Extreme" = paste0('Extreme drought \n(',drought_perc_change[3],'%)')), .multi_line = TRUE)) +
  facet_grid(~ Row,  labeller = labeller(Row = c("Moderate" = paste0('Moderate drought (',drought_perc_change[1],'%)'),
                                                 "Severe" = paste0('Severe drought (',drought_perc_change[2],'%)'),
                                                 "Extreme" = paste0('Extreme drought (',drought_perc_change[3],'%)')), .multi_line = TRUE)) +
  scale_fill_manual(values = c("No_stress" = "#fdcc8a", "moderate_stress" = "#fc8d59",
                               "stress" = "#e34a33", "severe_stress" = "#b30000"),
                    labels = c("No stress (0-10)", "Moderate stress (10-20)", "Water stressed (20-40)", "Severe stress (>40)")) +
  guides(fill = guide_legend(title = "Water stress (WEI+)")) +
  theme_bw() +
  theme(panel.border = element_blank(),
        panel.grid = element_blank(),
        panel.grid.major.y = element_line(color = "gray", linetype = "dashed", size = 0.5),
        strip.text = element_text(size = 14, face = "bold"),
        strip.background = element_blank(),
        axis.text.x = element_text(size = 12),
        axis.text.y = element_text(size = 12),
        axis.ticks = element_blank(),  # Remove axis tick marks
        axis.title.x = element_blank(),  # Remove x-axis title
        axis.title.y = element_blank()) +
  scale_x_discrete(labels = c("2000-2009", "2010-2019"))+
  scale_y_continuous(breaks = seq(0, 100, by = 20),labels = c('0%','20%','40%','60%','80%','100%'))

png(file=paste(path.intermediate_data, 'figures/5_Water_stress_2000-2009_vs_2010-2020_fin/plot_spei_',spei_index,'_target_mon_',target_months_name,'_WEI_quaterly_',seas_wei_name,'_Eur_region_',part_of_europe,'_regions_with_all_values.png', sep=""), width = 10, height = 7,  units = "in", res = 150)
print(plot)  # Replace ggplot_object with your actual ggplot object
dev.off()

# Write data for LANCET data sharing - For box plot

# combined_df_data_sharing <- combined_df_long %>%
#   mutate(
#     Year = case_when(
#       Year == "Past 10" ~ "2000-2009",
#       Year == "Recent 10" ~ "2010-2019",
#       TRUE ~ Year
#     ),
#     Row = case_when(
#       Row == "Moderate" ~ "Moderate drought",
#       Row == "Severe" ~ "Severe drought",
#       Row == "Extreme" ~ "Extreme drought",
#       TRUE ~ Row
#     ),
#     Stress_Level = case_when(
#       Stress_Level == "No_stress" ~ "No stress (0-10)",
#       Stress_Level == "moderate_stress" ~ "Moderate stress (10-20)",
#       Stress_Level == "stress" ~ "Water stressed (20-40)",
#       Stress_Level == "severe_stress" ~ "Severe stress (>40)",
#       TRUE ~ Stress_Level
#     )
#   )
# 
# combined_df_data_sharing <- combined_df_data_sharing %>%
#   rename(
#     Drought_category = Row,
#     Considered_years = Year,
#     WEIplus_Stress_levels = Stress_Level,
#     Percentage = Value
#   )
# 
# 
# # Data frame for drought_perc_change
# 
# df_drought_perc_change_past_10 <- data.frame(
#   Row = factor(c('Moderate', 'Severe', 'Extreme'), levels = c('Moderate', 'Severe', 'Extreme')),
#   `Percentage_change` = c(0,0,0))
# df_drought_perc_change_recent_10 <- data.frame(
#   Row = factor(c('Moderate', 'Severe', 'Extreme'), levels = c('Moderate', 'Severe', 'Extreme')),
#   `Percentage_change` = drought_perc_change)  
# 
# combined_df_drought_perc_change <- rbind(cbind(df_drought_perc_change_past_10, Year = "2000-2009"), cbind(df_drought_perc_change_recent_10, Year = "2010-2019"))
# 
# combined_df_drought_perc_change <- combined_df_drought_perc_change %>%
#   rename(
#     Drought_category = Row,
#     Considered_years = Year,
#     Percentage_change = Percentage_change
#   )
# # Keep Considered_years as center row
# combined_df_drought_perc_change <- combined_df_drought_perc_change %>%
#   select(Drought_category, Considered_years, Percentage_change)
# 
# # Write the first dataframe to a text file
# write.table(combined_df_data_sharing, file = paste(path.final_data, 'data_SPEI_',spei_index,'-',target_months_name,'_WEIplus_',seas_wei_name,'_Eur_region_',part_of_europe,'.csv', sep=""), sep = ",", col.names = NA, qmethod = "double")
# # Add an empty line (gap) between the dataframes
# cat("\n", file = paste(path.final_data, 'data_SPEI_',spei_index,'-',target_months_name,'_WEIplus_',seas_wei_name,'_Eur_region_',part_of_europe,'.csv', sep=""),  append = TRUE, sep = ",")
# # Write the second dataframe to the same text file in append mode
# write.table(combined_df_drought_perc_change, file = paste(path.final_data, 'data_SPEI_',spei_index,'-',target_months_name,'_WEIplus_',seas_wei_name,'_Eur_region_',part_of_europe,'.csv', sep=""), append = TRUE, sep = ",", col.names = NA, qmethod = "double")

}
}
