PETx <- function(tmean_mod=NA, tmax_mod=NA, tmin_mod=NA, u2_mod=NA, rs_mod=NA, tdew_mod=NA, ps_mod=NA, pet_method=NA, lat, na.rm=FALSE){
 
  # For PET computation 
  # lat <- lat

  if (pet_method=='thornthwaite') {
    
      ftime= as.numeric(dim(tmean_mod)['time'])
      n_sdates= as.numeric(dim(tmean_mod)['sdate'])

      tmean_mod_temp <- as.vector(tmean_mod)
      
      # Computing Potential EvapoTranspiration
      x_PET <- thornthwaite(tmean_mod_temp, lat=lat, na.rm=TRUE)
      PET <- array(x_PET, dim = c(ftime,n_sdates))

 } 

  if (pet_method=='hargreaves') {

    ftime= as.numeric(dim(tmax_mod)['time'])
    n_sdates= as.numeric(dim(tmax_mod)['sdate'])
    
    tmax_mod_temp <- as.vector(tmax_mod)
    tmin_mod_temp <- as.vector(tmin_mod)
    
    # Computing Potential EvapoTranspiration
    x_PET <- hargreaves(Tmin=tmin_mod_temp, Tmax=tmax_mod_temp, Ra = NA, lat = lat, Pre = NA, na.rm = FALSE)
    PET <- array(x_PET, dim = c(ftime,n_sdates))

 }
  
  if (pet_method=='penman') {
    
    ftime= as.numeric(dim(tmax_mod)['time'])
    n_sdates= as.numeric(dim(tmax_mod)['sdate'])
    
    tmax_mod_temp <- as.vector(tmax_mod)
    tmin_mod_temp <- as.vector(tmin_mod)
    u2_mod_temp <- as.vector(u2_mod)
    rs_mod_temp <- as.vector(rs_mod)
    tdew_mod_temp <- as.vector(tdew_mod)
    ps_mod_temp <- as.vector(ps_mod)
    lat <- lat
    
    if(length(lat) > 1){
      stop("length of lat > 1")
    }

    # Computing Potential EvapoTranspiration
    x_PET <- penman(Tmin=tmin_mod_temp, Tmax=tmax_mod_temp, U2=u2_mod_temp ,Rs=rs_mod_temp , Tdew=tdew_mod_temp, P=ps_mod_temp, lat = lat,
                    Ra = NULL, tsun = NULL, CC = NULL, ed = NULL, RH = NULL, P0 = NULL, z = NULL,CO2 = NULL, na.rm = FALSE, verbose = FALSE, method = "FAO")
    #PET <- as.vector(x_PET)
    PET <- array(x_PET, dim = c(ftime,n_sdates))

  }
  
return(PET)
   
}
  
  
